@@ -31,7 +31,7 @@ from gitlab.exceptions import *  # noqa
 from gitlab import utils  # noqa
 
 __title__ = "python-gitlab"
-__version__ = "1.11.0"
+__version__ = "1.13.0"
 __author__ = "Gauvain Pocentek"
 __email__ = "gauvainpocentek@gmail.com"
 __license__ = "LGPL3"
@@ -60,6 +60,7 @@ class Gitlab(object):
         url (str): The URL of the GitLab server.
         private_token (str): The user private token
         oauth_token (str): An oauth token
+        job_token (str): A CI job token
         email (str): The user email or login.
         password (str): The user password (associated with email).
         ssl_verify (bool|str): Whether SSL certificates should be validated. If
@@ -76,8 +77,7 @@ class Gitlab(object):
         url,
         private_token=None,
         oauth_token=None,
-        email=None,
-        password=None,
+        job_token=None,
         ssl_verify=True,
         http_username=None,
         http_password=None,
@@ -94,12 +94,8 @@ class Gitlab(object):
         #: Timeout to use for requests to gitlab server
         self.timeout = timeout
         #: Headers that will be used in request to GitLab
-        self.headers = {}
+        self.headers = {"User-Agent": "%s/%s" % (__title__, __version__)}
 
-        #: The user email
-        self.email = email
-        #: The user password (associated with email)
-        self.password = password
         #: Whether SSL certificates should be validated
         self.ssl_verify = ssl_verify
 
@@ -107,6 +103,7 @@ class Gitlab(object):
         self.http_username = http_username
         self.http_password = http_password
         self.oauth_token = oauth_token
+        self.job_token = job_token
         self._set_auth_info()
 
         #: Create a session object for requests
@@ -195,6 +192,7 @@ class Gitlab(object):
             config.url,
             private_token=config.private_token,
             oauth_token=config.oauth_token,
+            job_token=config.job_token,
             ssl_verify=config.ssl_verify,
             timeout=config.timeout,
             http_username=config.http_username,
@@ -211,20 +209,6 @@ class Gitlab(object):
         The `user` attribute will hold a `gitlab.objects.CurrentUser` object on
         success.
         """
-        if self.private_token or self.oauth_token:
-            self._token_auth()
-        else:
-            self._credentials_auth()
-
-    def _credentials_auth(self):
-        data = {"email": self.email, "password": self.password}
-        r = self.http_post("/session", data)
-        manager = self._objects.CurrentUserManager(self)
-        self.user = self._objects.CurrentUser(manager, r)
-        self.private_token = self.user.private_token
-        self._set_auth_info()
-
-    def _token_auth(self):
         self.user = self._objects.CurrentUserManager(self).get()
 
     def version(self):
@@ -346,9 +330,15 @@ class Gitlab(object):
             return url
 
     def _set_auth_info(self):
-        if self.private_token and self.oauth_token:
+        tokens = [
+            token
+            for token in [self.private_token, self.oauth_token, self.job_token]
+            if token
+        ]
+        if len(tokens) > 1:
             raise ValueError(
-                "Only one of private_token or oauth_token should " "be defined"
+                "Only one of private_token, oauth_token or job_token should "
+                "be defined"
             )
         if (self.http_username and not self.http_password) or (
             not self.http_username and self.http_password
@@ -364,12 +354,19 @@ class Gitlab(object):
 
         self._http_auth = None
         if self.private_token:
-            self.headers["PRIVATE-TOKEN"] = self.private_token
             self.headers.pop("Authorization", None)
+            self.headers["PRIVATE-TOKEN"] = self.private_token
+            self.headers.pop("JOB-TOKEN", None)
 
         if self.oauth_token:
             self.headers["Authorization"] = "Bearer %s" % self.oauth_token
             self.headers.pop("PRIVATE-TOKEN", None)
+            self.headers.pop("JOB-TOKEN", None)
+
+        if self.job_token:
+            self.headers.pop("Authorization", None)
+            self.headers.pop("PRIVATE-TOKEN", None)
+            self.headers["JOB-TOKEN"] = self.job_token
 
         if self.http_username:
             self._http_auth = requests.auth.HTTPBasicAuth(
